@@ -133,6 +133,7 @@ nsEnigMsgCompose::nsEnigMsgCompose()
     mRequestStopped(PR_FALSE),
 
     mLinebreak(PR_TRUE),
+    mSpace(0),
     mMatchFrom(0),
 
     mInputLen(0),
@@ -735,11 +736,19 @@ nsEnigMsgCompose::MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen)
     return WriteCopy(aBuf, aLen);
   }
 
-  // Mangle lines beginning with "From " prior to signing
+  // Mangle lines beginning with "From "
+  // strip trailing whitespaces prior to signing
   PRUint32 offset = 0;
+  PRUint32 writeCount = 0;
 
   for (PRUint32 j=0; j<((PRUint32) aLen); j++) {
-
+    if ((mSpace > 0) && ((aBuf[j] == '\r') || (aBuf[j] == '\n'))) {
+      // strip trailing spaces and tabs
+      writeCount = j-offset-mSpace;
+      WriteCopy(&aBuf[offset], writeCount);
+      DEBUG_LOG(("nsEnigMsgCompose::MimeCryptoWriteBlock: stripped trailing whitespaces\n"));
+      offset = j;
+    }
     if (mLinebreak || (mMatchFrom > 0)) {
 
       if (aBuf[j] != FromStr[mMatchFrom]) {
@@ -753,7 +762,7 @@ nsEnigMsgCompose::MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen)
         if (mMatchFrom >= strlen(FromStr)) {
           // Complete match found
           // Write out characters preceding match
-          PRUint32 writeCount = j+1-offset-mMatchFrom;
+          writeCount = j+1-offset-mMatchFrom;
 
           if (writeCount > 0) {
             rv = WriteCopy(&aBuf[offset], writeCount);
@@ -777,11 +786,17 @@ nsEnigMsgCompose::MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen)
     }
 
     mLinebreak = (aBuf[j] == '\r') || (aBuf[j] == '\n');
+    if ((aBuf[j] == ' ') || (aBuf[j] == '\t')) {
+      ++mSpace;
+    }
+    else {
+      mSpace = 0;
+    }
   }
 
   if ((offset+mMatchFrom) < (PRUint32) aLen) {
     // Write out characters preceding any match
-    rv = WriteCopy(&aBuf[offset], aLen-offset-mMatchFrom);
+    rv = WriteCopy(&aBuf[offset], aLen-offset-mMatchFrom-mSpace);
     if (NS_FAILED(rv)) return rv;
   }
 
