@@ -34,8 +34,8 @@ GPL.
 // enigmailCommon.js: shared JS functions for Enigmail
 
 // This Enigmail version and compatible Enigmime version
-var gEnigmailVersion = "0.86.1.0";
-var gEnigmimeVersion = "0.86.1.0";
+var gEnigmailVersion = "0.90.0.0";
+var gEnigmimeVersion = "0.90.0.0";
 
 // Maximum size of message directly processed by Enigmail
 const ENIG_MSG_BUFFER_SIZE = 96000;
@@ -76,11 +76,11 @@ const ENIG_ISCRIPTABLEUNICODECONVERTER_CONTRACTID = "@mozilla.org/intl/scriptabl
 const ENIG_IOSERVICE_CONTRACTID = "@mozilla.org/network/io-service;1";
 
 const ENIGMAIL_PREFS_ROOT       = "extensions.enigmail.";
-
+const ENIG_C = Components;
 
 // Interfaces
-const nsIEnigmail               = Components.interfaces.nsIEnigmail;
-const nsIEnigStrBundle          = Components.interfaces.nsIStringBundleService;
+const nsIEnigmail               = ENIG_C.interfaces.nsIEnigmail;
+const nsIEnigStrBundle          = ENIG_C.interfaces.nsIStringBundleService;
 
 // Encryption flags
 if (nsIEnigmail) {
@@ -124,8 +124,7 @@ var gEnigDebugLog;
 
 var gEnigPrefSvc, gEnigPrefRoot, gPrefEnigmail;
 try {
-  gEnigPrefSvc = Components.classes["@mozilla.org/preferences-service;1"]
-                             .getService(Components.interfaces.nsIPrefService);
+  gEnigPrefSvc = enigGetService("@mozilla.org/preferences-service;1", "nsIPrefService");
 
   gEnigPrefRoot        = gEnigPrefSvc.getBranch(null);
   gPrefEnigmail = gEnigPrefSvc.getBranch(ENIGMAIL_PREFS_ROOT);
@@ -140,7 +139,6 @@ try {
 function EnigGetFrame(win, frameName) {
   DEBUG_LOG("enigmailCommon.js: EnigGetFrame: name="+frameName+"\n");
   for (var j=0; j<win.frames.length; j++) {
-    dump(win.frames[j].name+"\n");
     if (win.frames[j].name == frameName) {
       return win.frames[j];
     }
@@ -157,14 +155,14 @@ var gEnigStrBundle;
 function EnigInitCommon(id) {
    DEBUG_LOG("enigmailCommon.js: EnigInitCommon: id="+id+"\n");
 
-   gEnigPromptSvc = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
+   gEnigPromptSvc = enigGetService("@mozilla.org/embedcomp/prompt-service;1", "nsIPromptService");
 
    // Do not instantiate ProcessInfo for Prefs
    if (id && (id.indexOf("pref-") == 0))
      return;
 
    try {
-     var processInfo = Components.classes[ENIG_PROCESSINFO_CONTRACTID].getService(Components.interfaces.nsIProcessInfo);
+     var processInfo = enigGetService(ENIG_PROCESSINFO_CONTRACTID, "nsIProcessInfo");
 
      var nspr_log_modules = processInfo.getEnv("NSPR_LOG_MODULES");
 
@@ -191,7 +189,7 @@ function GetEnigmailSvc() {
   }
 
   try {
-    gEnigmailSvc = Components.classes[ENIG_ENIGMAIL_CONTRACTID].createInstance(Components.interfaces.nsIEnigmail);
+    gEnigmailSvc = ENIG_C.classes[ENIG_ENIGMAIL_CONTRACTID].createInstance(ENIG_C.interfaces.nsIEnigmail);
 
   } catch (ex) {
     ERROR_LOG("enigmailCommon.js: Error in instantiating EnigmailService\n");
@@ -251,11 +249,26 @@ function GetEnigmailSvc() {
   return gEnigmailSvc.initialized ? gEnigmailSvc : null;
 }
 
+
 function EnigUpdate_0_80() {
   try {
     var oldVer=EnigGetPref("configuredVersion");
 
     if (oldVer.substring(0,1)=="0"){
+      if ((oldVer.substring(0,4)<"0.89") && (navigator.vendor=="Thunderbird")) {
+        // uninstall globally installed enigmime on Thunderbird
+        var ioService = enigGetService("@mozilla.org/network/io-service;1", "nsIIOService");
+        var sysCompDir = this.gDirService.get("ComsD", ENIG_C.interfaces.nsIFile);
+        
+        for (var f in [ "enigmime.xpt", "libenigmime.so", "enigmail.dll", "libenigmime.dylib" ]) {
+          var compFile = sysCompDir.clone();
+          compFile.append(f);
+          try {
+            if (compFile.exists()) compFile.remove(false);
+          }
+          catch (ex) {}
+        }
+      }        
       if (oldVer.substring(0,4)<"0.83") {
         var keySrv = EnigGetPref("keyserver");
         if (keySrv.indexOf(",") == -1) {
@@ -268,8 +281,8 @@ function EnigUpdate_0_80() {
         }
       }
       if (oldVer.substring(0,4)<"0.81") {
-        window.openDialog("chrome://enigmail/content/enigmailUpgrade.xul",
-            "", "dialog,modal,centerscreen");
+        window.open("chrome://enigmail/content/enigmailUpgrade.xul",
+            "", "chrome,modal,centerscreen");
       }
     }
   }
@@ -319,7 +332,7 @@ function EnigConfigure() {
   if (buttonPressed == 0) {
     // Configure now
     EnigPrefWindow(true,(navigator.vendor=="Thunderbird" ? "thunderbird" : "seamonkey"));
-
+                             
   } else {
     // "Do not ask me again" => "already configured"
     EnigSetPref("configuredVersion", gEnigmailVersion);
@@ -342,14 +355,14 @@ function EnigCreateFileStream(filePath, permissions) {
   //DEBUG_LOG("enigmailCommon.js: EnigCreateFileStream: file="+filePath+"\n");
 
   try {
-    var localFile = Components.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(Components.interfaces.nsILocalFile);
+    var localFile = ENIG_C.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(ENIG_C.interfaces.nsILocalFile);
 
     localFile.initWithPath(filePath);
 
     if (localFile.exists()) {
 
       if (localFile.isDirectory() || !localFile.isWritable())
-         throw Components.results.NS_ERROR_FAILURE;
+         throw ENIG_C.results.NS_ERROR_FAILURE;
 
       if (!permissions)
         permissions = localFile.permissions;
@@ -360,7 +373,7 @@ function EnigCreateFileStream(filePath, permissions) {
 
     var flags = ENIG_WRONLY | ENIG_CREATE_FILE | ENIG_TRUNCATE;
 
-    var fileStream = Components.classes[ENIG_LOCALFILEOUTPUTSTREAM_CONTRACTID].createInstance(Components.interfaces.nsIFileOutputStream);
+    var fileStream = ENIG_C.classes[ENIG_LOCALFILEOUTPUTSTREAM_CONTRACTID].createInstance(ENIG_C.interfaces.nsIFileOutputStream);
 
     fileStream.init(localFile, flags, permissions, 0);
 
@@ -381,7 +394,7 @@ function EnigWriteFileContents(filePath, data, permissions) {
 
     if (data.length) {
       if (fileOutStream.write(data, data.length) != data.length)
-        throw Components.results.NS_ERROR_FAILURE;
+        throw ENIG_C.results.NS_ERROR_FAILURE;
 
       fileOutStream.flush();
     }
@@ -400,15 +413,15 @@ function EnigReadURLContents(url, maxBytes) {
   DEBUG_LOG("enigmailCommon.js: EnigReadURLContents: url="+url+
             ", "+maxBytes+"\n");
 
-  var ioServ = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
+  var ioServ = enigGetService(ENIG_IOSERVICE_CONTRACTID, "nsIIOService");
   if (!ioServ)
-    throw Components.results.NS_ERROR_FAILURE;
+    throw ENIG_C.results.NS_ERROR_FAILURE;
 
   var fileChannel = ioServ.newChannel(url, null, null)
 
   var rawInStream = fileChannel.open();
 
-  var scriptableInStream = Components.classes[ENIG_SCRIPTABLEINPUTSTREAM_CONTRACTID].createInstance(Components.interfaces.nsIScriptableInputStream);
+  var scriptableInStream = ENIG_C.classes[ENIG_SCRIPTABLEINPUTSTREAM_CONTRACTID].createInstance(ENIG_C.interfaces.nsIScriptableInputStream);
   scriptableInStream.init(rawInStream);
 
   var available = scriptableInStream.available()
@@ -429,11 +442,11 @@ function EnigReadFileContents(localFile, maxBytes) {
             ", "+maxBytes+"\n");
 
   if (!localFile.exists() || !localFile.isReadable())
-    throw Components.results.NS_ERROR_FAILURE;
+    throw ENIG_C.results.NS_ERROR_FAILURE;
 
-  var ioServ = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
+  var ioServ = enigGetService(ENIG_IOSERVICE_CONTRACTID, "nsIIOService");
   if (!ioServ)
-    throw Components.results.NS_ERROR_FAILURE;
+    throw ENIG_C.results.NS_ERROR_FAILURE;
 
   var fileURI = ioServ.newFileURI(localFile);
   return EnigReadURLContents(fileURI.asciiSpec, maxBytes);
@@ -443,7 +456,8 @@ function EnigReadFileContents(localFile, maxBytes) {
 ///////////////////////////////////////////////////////////////////////////////
 
 function WRITE_LOG(str) {
-  dump(str);
+  if (gEnigLogLevel >= 4)
+    dump(str);
 
   if (gEnigDebugLog && gEnigmailSvc && gEnigmailSvc.logFileStream) {
     gEnigmailSvc.logFileStream.write(str, str.length);
@@ -479,6 +493,11 @@ function EnigAlert(mesg) {
   gEnigPromptSvc.alert(window, EnigGetString("enigAlert"), mesg);
 }
 
+function EnigLongAlert(mesg) {
+  window.openDialog("chrome://enigmail/content/enigmailAlertDlg.xul",
+            "", "chrome,modal,centerscreen", {msgtext: mesg});
+}
+
 function EnigAlertCount(countPrefName, mesg) {
   var alertCount = EnigGetPref(countPrefName);
 
@@ -594,6 +613,7 @@ function EnigOverrideAttribute(elementIdList, attrName, prefix, suffix) {
 
 
 function EnigPrefWindow(showBasic, clientType, selectTab) {
+  DEBUG_LOG("enigmailCommon.js: EnigPrefWindow\n");
   window.openDialog("chrome://enigmail/content/pref-enigmail.xul",
                     "_blank", "chrome,resizable=yes",
                     {'showBasic': showBasic,
@@ -608,16 +628,13 @@ function EnigAdvPrefWindow() {
 
 function EnigHelpWindow(source) {
 
-  var input="chrome://enigmail/locale/help/"+source+".html";
-
   EnigOpenWin("enigmail:help",
-              "chrome://enigmail/content/enigmailHelp.xul",
-              "chrome,resizable",
-              input);
+              "chrome://enigmail/content/enigmailHelp.xul?src="+source,
+              "centerscreen,resizable");
 }
 
 function EnigUpgrade() {
-  var ioService = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
+  var ioService = ENIG_C.classes[ENIG_IOSERVICE_CONTRACTID].getService(ENIG_C.interfaces.nsIIOService);
   if (ioService && ioService.offline) {
     EnigAlert(EnigGetString("needOnline"));
     return;
@@ -776,6 +793,7 @@ function EnigSetPref(prefName, value) {
 }
 
 function EnigGetSignMsg(identity) {
+  DEBUG_LOG("enigmailCommon.js: EnigGetSignMsg: identity.key="+identity.key+"\n");
   var sign = null;
 
   if (gEnigPrefRoot.getPrefType("mail.identity."+identity.key+".pgpSignPlain")==0) {
@@ -807,9 +825,9 @@ EnigRequestObserver.prototype = {
   _terminateArg: null,
 
   QueryInterface: function (iid) {
-    if (!iid.equals(Components.interfaces.nsIRequestObserver) &&
-        !iid.equals(Components.interfaces.nsISupports))
-      throw Components.results.NS_ERROR_NO_INTERFACE;
+    if (!iid.equals(ENIG_C.interfaces.nsIRequestObserver) &&
+        !iid.equals(ENIG_C.interfaces.nsISupports))
+      throw ENIG_C.results.NS_ERROR_NO_INTERFACE;
     return this;
   },
 
@@ -834,7 +852,7 @@ function EnigConvertFromUnicode(text, charset) {
 
   // Encode plaintext
   try {
-    var unicodeConv = Components.classes[ENIG_ISCRIPTABLEUNICODECONVERTER_CONTRACTID].getService(Components.interfaces.nsIScriptableUnicodeConverter);
+    var unicodeConv = ENIG_C.classes[ENIG_ISCRIPTABLEUNICODECONVERTER_CONTRACTID].getService(ENIG_C.interfaces.nsIScriptableUnicodeConverter);
 
     unicodeConv.charset = charset;
     return unicodeConv.ConvertFromUnicode(text);
@@ -855,7 +873,7 @@ function EnigConvertToUnicode(text, charset) {
 
   // Encode plaintext
   try {
-    var unicodeConv = Components.classes[ENIG_ISCRIPTABLEUNICODECONVERTER_CONTRACTID].getService(Components.interfaces.nsIScriptableUnicodeConverter);
+    var unicodeConv = ENIG_C.classes[ENIG_ISCRIPTABLEUNICODECONVERTER_CONTRACTID].getService(ENIG_C.interfaces.nsIScriptableUnicodeConverter);
 
     unicodeConv.charset = charset;
     return unicodeConv.ConvertToUnicode(text);
@@ -876,7 +894,6 @@ function EnigConvertGpgToUnicode(text) {
       var ch=text.substr(a,2).toSource().substr(13,8).replace(/\\x/g, "\\u00");
       var newCh=EnigConvertToUnicode(EnigConvertToUnicode(ch, "x-u-escaped"), "utf-8");
       if (newCh != ch) {
-        //dump(ch+"\n");
         var r=new RegExp(text.substr(a, 2), "g");
         text=text.replace(r, newCh);
       }
@@ -886,11 +903,43 @@ function EnigConvertGpgToUnicode(text) {
         a += b+2;
       }
     }
-  }  
+    
+    a=text.search(/\\x3a/i);
+    if (a>0) {
+      text = text.replace(/\\x3a/ig, "\\e3A");
+    }
+
+    a=text.search(/\\x/);
+    while (a>=0) {
+      ch=text.substr(a,4).replace(/\\x/g, "\\u00");
+      newCh=EnigConvertToUnicode(ch, "x-u-escaped");
+      if (newCh != ch) {
+        r=new RegExp("\\"+text.substr(a, 4), "g");
+        text=text.replace(r, newCh);
+      }
+      a=text.search(/\\x/);
+    }
+  }
+
   return text;
 } 
 
 
+function EnigFormatFpr(fingerprint) {
+  // format key fingerprint
+  DEBUG_LOG("enigmailCommon.js: EnigFormatFpr: fingerprint="+fingerprint+"\n");
+  
+  var r="";
+  var fpr = fingerprint.match(/(....)(....)(....)(....)(....)(....)(....)(....)(....)?(....)?/);
+  if (fpr && fpr.length > 2) {
+    fpr.shift();
+    r=fpr.join(" ");
+  }
+
+  return r;
+}
+
+
 function EnigGetDeepText(node, findStr) {
 
   DEBUG_LOG("enigmailCommon.js: EnigDeepText: <" + node.tagName + ">, '"+findStr+"'\n");
@@ -1021,9 +1070,9 @@ function EnigClearPassphrase() {
 }
 
 function EnigOpenWin (winName, spec, winOptions, optList) {
-  var windowManager = Components.classes[ENIG_APPSHELL_MEDIATOR_CONTRACTID].getService(Components.interfaces.nsIWindowMediator);
+  var windowManager = ENIG_C.classes[ENIG_APPSHELL_MEDIATOR_CONTRACTID].getService(ENIG_C.interfaces.nsIWindowMediator);
 
-  /* although accordign to the docs, this doesn't seem to work ...
+  /* according to the docs, this doesn't seem to work ...
     var recentWin = windowManager.getMostRecentWindow(winName);
   */
   var winEnum=windowManager.getEnumerator(null);
@@ -1038,26 +1087,40 @@ function EnigOpenWin (winName, spec, winOptions, optList) {
   if (recentWin) {
     recentWin.focus();
   } else {
-    var appShellSvc = Components.classes[ENIG_ASS_CONTRACTID].getService(Components.interfaces.nsIAppShellService);
+    var appShellSvc = ENIG_C.classes[ENIG_ASS_CONTRACTID].getService(ENIG_C.interfaces.nsIAppShellService);
     var domWin = appShellSvc.hiddenDOMWindow;
-
-    domWin.openDialog(spec, winName, winOptions, optList);
+    //nsIDOMJSWindow
+    domWin.open(spec, winName, "chrome,"+winOptions, optList);
   }
 }
 
+// return the options passed to a window
+function EnigGetWindowOptions() {
+  var winOptions=[];
+  if (window.location.search) {
+    var optList=window.location.search.substr(1).split(/\&/);
+    for (var i=0; i<optList.length; i++) {
+      var anOption=optList[i].split(/\=/);
+      winOptions[anOption[0]] = unescape(anOption[1]);
+    }
+  }
+  return winOptions;
+}
+
 function EnigViewAbout() {
   DEBUG_LOG("enigmailCommon.js: EnigViewAbout\n");
-
+  
   EnigOpenWin ("about:enigmail",
                "chrome://enigmail/content/enigmailAbout.xul",
-               "resizable,chrome");
+               "resizable,centerscreen");
 }
 
 function EnigViewConsole() {
   DEBUG_LOG("enigmailCommon.js: EnigViewConsole\n");
 
   EnigOpenWin("enigmail:console",
-              "chrome://enigmail/content/enigmailConsole.xul", "chrome,resizable");
+              "chrome://enigmail/content/enigmailConsole.xul",
+              "resizable,centerscreen");
 }
 
 function EnigViewDebugLog() {
@@ -1085,11 +1148,11 @@ function EnigViewDebugLog() {
   logDirectory = logDirectory.replace(/\\/g, "/");
 
   var logFileURL = "file:///" + logDirectory + "/enigdbug.txt";
+  var opts="fileUrl="+escape(logFileURL)+"&title="+escape("Enigmail Debug Log");
 
   EnigOpenWin("enigmail:logFile",
-              "chrome://enigmail/content/enigmailViewFile.xul",
-              "chrome,resizable",
-              [ logFileURL, "Enigmail Debug Log"]);
+              "chrome://enigmail/content/enigmailViewFile.xul?"+opts,
+              "resizable,centerscreen");
 
 //  window.open(logFileURL, 'Enigmail Debug Log');
 }
@@ -1098,11 +1161,18 @@ function EnigKeygen() {
   DEBUG_LOG("enigmailCommon.js: EnigKeygen\n");
 
   window.openDialog('chrome://enigmail/content/enigmailKeygen.xul',
-                    EnigGetString('keyGeneration'),
-                    'chrome,dialog,modal,close=no,resizable=yes,width=600');
+                    "enigmail:generateKey",
+                    'chrome,dialog,modal,resizable=yes,width=600');
 
 }
 
+function EnigKeyManager() {
+  DEBUG_LOG("enigmailCommon.js: EnigKeygen\n");
+  EnigOpenWin("enigmail:KeyManager",
+              "chrome://enigmail/content/enigmailKeyManager.xul",
+              "resizable");
+}
+
 // retrieves the most recent navigator window (opens one if need be)
 function EnigLoadURLInNavigatorWindow(url, aOpenFlag)
 {
@@ -1121,14 +1191,7 @@ function EnigLoadURLInNavigatorWindow(url, aOpenFlag)
   // if not, get the most recently used browser window
   if (!navWindow) {
     var wm;
-    try {
-      // Mozilla up to 1.0
-      wm = Components.classes[ENIG_WMEDIATOR_CONTRACTID].getService(Components.interfaces.nsIWindowMediator);
-    }
-    catch (ex) {
-      // Mozilla 1.1 and newer
-      wm = Components.classes[ENIG_APPSHELL_MEDIATOR_CONTRACTID].getService(Components.interfaces.nsIWindowMediator);
-    }
+    wm = ENIG_C.classes[ENIG_APPSHELL_MEDIATOR_CONTRACTID].getService(ENIG_C.interfaces.nsIWindowMediator);
     navWindow = wm.getMostRecentWindow("navigator:browser");
   }
 
@@ -1154,7 +1217,7 @@ function EnigGetString(aStr) {
   var restCount = arguments.length - 1;
   if(!gEnigStrBundle) {
     try {
-      var strBundleService = Components.classes[ENIG_STRINGBUNDLE_CONTRACTID].getService();
+      var strBundleService = ENIG_C.classes[ENIG_STRINGBUNDLE_CONTRACTID].getService();
       strBundleService = strBundleService.QueryInterface(nsIEnigStrBundle);
       gEnigStrBundle = strBundleService.createBundle("chrome://enigmail/locale/enigmail.properties");
     } catch (ex) {
@@ -1189,7 +1252,7 @@ function EnigStripEmail(mailAddrs) {
      qEnd = mailAddrs.indexOf('"', qStart+1);
      if (qEnd == -1) {
        ERROR_LOG("enigmailMsgComposeOverlay.js: EnigStripEmail: Unmatched quote in mail address: "+mailAddrs+"\n");
-       throw Components.results.NS_ERROR_FAILURE;
+       throw ENIG_C.results.NS_ERROR_FAILURE;
      }
 
      mailAddrs = mailAddrs.substring(0,qStart) + mailAddrs.substring(qEnd+1);
@@ -1210,15 +1273,15 @@ function EnigGetTempDir() {
   var tmpDir;
 
   try {
-    var ds = Components.classes[ENIG_DIRSERVICE_CONTRACTID].getService();
-    var dsprops = ds.QueryInterface(Components.interfaces.nsIProperties);
-    var tmpDirComp = dsprops.get(ENIG_TEMPDIR_PROP, Components.interfaces.nsILocalFile);
+    var ds = ENIG_C.classes[ENIG_DIRSERVICE_CONTRACTID].getService();
+    var dsprops = ds.QueryInterface(ENIG_C.interfaces.nsIProperties);
+    var tmpDirComp = dsprops.get(ENIG_TEMPDIR_PROP, ENIG_C.interfaces.nsILocalFile);
     tmpDir=tmpDirComp.path;
   }
   catch (ex) {
     // let's guess ...
     var httpHandler = ioServ.getProtocolHandler("http");
-    httpHandler = httpHandler.QueryInterface(Components.interfaces.nsIHttpProtocolHandler);
+    httpHandler = httpHandler.QueryInterface(ENIG_C.interfaces.nsIHttpProtocolHandler);
     isWin = (httpHandler.platform.search(/Win/i) == 0);
     if (isWin) {
       tmpDir="C:\\TEMP";
@@ -1327,37 +1390,21 @@ function EnigReceiveKey(parent, msgParentWindow, recvFlags, keyId,
 
   if (progressBar) {
     // wait one second before displaying the progress bar
-    var progressParam=Components.classes["@mozilla.org/messengercompose/composeprogressparameters;1"].createInstance(Components.interfaces.nsIMsgComposeProgressParams);
+    var progressParam=ENIG_C.classes["@mozilla.org/messengercompose/composeprogressparameters;1"].createInstance(ENIG_C.interfaces.nsIMsgComposeProgressParams);
     parent.setTimeout(progressBar.openProgressDialog, 1000, parent, msgParentWindow, "chrome://enigmail/content/enigRetrieveProgress.xul", progressParam);
     //progressBar.openProgressDialog(parent, msgWindow, "chrome://enigmail/content/enigRetrieveProgress.xul", progressParam);
-    progressBar.onStateChange(null, null, Components.interfaces.nsIWebProgressListener.STATE_START, 0);
+    progressBar.onStateChange(null, null, ENIG_C.interfaces.nsIWebProgressListener.STATE_START, 0);
   }
 
   return enigmailSvc.receiveKey(recvFlags, keyserver, keyId, requestObserver, errorMsgObj);
 }
 
 
-function EnigUninstall() {
-  const JSLIB_MIN_VER="0.1.128";
-  if ((typeof(JS_LIB_VERSION) != "string") || (JS_LIB_VERSION < JSLIB_MIN_VER)) {
-    EnigAlert(EnigGetString("jslibNeeded", JSLIB_MIN_VER));
-    return;
-  }
-  window.close();
-  if (!EnigConfirm(EnigGetString("uninstallConfirm")))
-    return;
-
-  window.openDialog("chrome://enigmail/content/enigmailUninstall.xul",
-          "", "dialog,modal,centerscreen", {performUninst: true});
-
-  return;
-}
-
 function EnigFilePicker(title, displayDir, save, defaultExtension, defaultName, filterPairs) {
   DEBUG_LOG("enigmailCommon.js: EnigFilePicker: "+save+"\n");
 
-  const nsIFilePicker = Components.interfaces.nsIFilePicker;
-  var filePicker = Components.classes["@mozilla.org/filepicker;1"].createInstance();
+  const nsIFilePicker = ENIG_C.interfaces.nsIFilePicker;
+  var filePicker = ENIG_C.classes["@mozilla.org/filepicker;1"].createInstance();
   filePicker = filePicker.QueryInterface(nsIFilePicker);
 
   var mode = save ? nsIFilePicker.modeSave : nsIFilePicker.modeOpen;
@@ -1365,7 +1412,7 @@ function EnigFilePicker(title, displayDir, save, defaultExtension, defaultName,
   filePicker.init(window, title, mode);
 
   if (displayDir) {
-    var localFile = Components.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(Components.interfaces.nsILocalFile);
+    var localFile = ENIG_C.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(ENIG_C.interfaces.nsILocalFile);
 
     try {
       localFile.initWithPath(displayDir);
@@ -1393,7 +1440,7 @@ function EnigFilePicker(title, displayDir, save, defaultExtension, defaultName,
   if (filePicker.show() == nsIFilePicker.returnCancel)
     return null;
 
-  var file = filePicker.file.QueryInterface(Components.interfaces.nsILocalFile);
+  var file = filePicker.file.QueryInterface(ENIG_C.interfaces.nsILocalFile);
 
   return file;
 }
@@ -1419,15 +1466,154 @@ function EnigNewRule(emailAddress) {
   inputObj.toAddress="{"+emailAddress+"}";
   inputObj.options="";
   inputObj.command = "add";
-  window.openDialog("chrome://enigmail/content/enigmailSingleRcptSettings.xul","", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
+  window.openDialog("chrome://enigmail/content/enigmailSingleRcptSettings.xul","", 
+                    "dialog,modal,centerscreen,resizable", inputObj, resultObj);
   return true;
 }
 
-function EnigSetKeyTrust(parent, userId, keyId, trustLevel, exitCodeObj, errorMsgObj) {
+
+function EnigEditKeyTrust(userId, keyId) {
+  var inputObj = {
+    keyId: keyId,
+    userId: userId
+  }
+  window.openDialog("chrome://enigmail/content/enigmailEditKeyTrustDlg.xul","", "dialog,modal,centerscreen,resizable", inputObj);
+}
+
+
+function EnigSignKey(userId, keyId, signingKeyHint) {
+  var inputObj = {
+    keyId: keyId,
+    userId: userId,
+    signingKeyHint: signingKeyHint
+  }
+  window.openDialog("chrome://enigmail/content/enigmailSignKeyDlg.xul","", "dialog,modal,centerscreen,resizable", inputObj);
+}
+
+function EnigShowPhoto(keyId, userId) {
+  var enigmailSvc = GetEnigmailSvc();
+  if (enigmailSvc) {
+    var exitCodeObj = new Object();
+    var errorMsgObj = new Object();
+    var photoPath = enigmailSvc.showKeyPhoto("0x"+keyId, exitCodeObj, errorMsgObj);
+    if (photoPath && exitCodeObj.value==0) {
+      var photoFile = Components.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(Components.interfaces.nsILocalFile);
+      photoFile.initWithPath(photoPath);
+      if (! (photoFile.isFile() && photoFile.isReadable())) {
+        EnigAlert("Photo path '"+photoPath+"' is not readable");
+      }
+      else {
+        var ioServ = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
+        var photoUri = ioServ.newFileURI(photoFile).spec;
+        var argsObj = {
+          photoUri: photoUri,
+          userId: userId,
+          keyId: keyId
+        };
+        window.openDialog("chrome://enigmail/content/enigmailDispPhoto.xul",photoUri, "chrome,modal=1,resizable=1,dialog=1,centerscreen", argsObj);
+        try {
+          // delete the photo file
+          photoFile.remove(false);
+        }
+        catch (ex) {}
+     }
+    }
+    else {
+      EnigAlert(EnigGetString("noPhotoAvailable"));
+    }
+  }
+}
+
+function EnigCreateRevokeCert(keyId, userId) {
+  var defaultFileName = userId.replace(/[\<\>]/g, "");
+  defaultFileName += " (0x"+keyId.substr(-8,8)+") rev.asc"
+  var outFile = EnigFilePicker(EnigGetString("saveRevokeCertAs"),
+                               "", true, "*.asc",
+                               defaultFileName,
+                               [EnigGetString("asciiArmorFile"), "*.asc"]);
+  if (! outFile) return -1;
 
   var enigmailSvc = GetEnigmailSvc();
   if (!enigmailSvc)
-    return false;
-  var r = enigmailSvc.setKeyTrust(parent, userId, keyId, trustLevel, exitCodeObj, errorMsgObj);
+    return -1;
+
+  var errorMsgObj = {};
+  var r=enigmailSvc.genRevokeCert(window, "0x"+keyId, outFile.path, "1", "", errorMsgObj);
+  if (r != 0) {
+    EnigAlert(EnigGetString("revokeCertFailed")+"\n\n"+errorMsgObj.value);
+  }
+  else {
+    EnigAlert(EnigGetString("revokeCertOK"));
+  }
   return r;
-}
\ No newline at end of file
+}
+
+
+// return the label of trust for a given trust code
+function EnigGetTrustLabel(trustCode) {
+  var keyTrust;
+  switch (trustCode) {
+  case 'q':
+    keyTrust=EnigGetString("keyValid.unknown");
+    break;
+  case 'i':
+    keyTrust=EnigGetString("keyValid.invalid");
+    break;
+  case 'd':
+    keyTrust=EnigGetString("keyValid.disabled");
+    break;
+  case 'r':
+    keyTrust=EnigGetString("keyValid.revoked");
+    break;
+  case 'e':
+    keyTrust=EnigGetString("keyValid.expired");
+    break;
+  case 'n':
+    keyTrust=EnigGetString("keyTrust.untrusted");
+    break;
+  case 'm':
+    keyTrust=EnigGetString("keyTrust.marginal");
+    break;
+  case 'f':
+    keyTrust=EnigGetString("keyTrust.full");
+    break;
+  case 'u':
+    keyTrust=EnigGetString("keyTrust.ultimate");
+    break;
+  case '-':
+    keyTrust="-";
+    break;
+  default:
+    keyTrust="";
+  }
+  return keyTrust;
+}
+
+function enigCreateInstance (aURL, aInterface) 
+{
+  return ENIG_C.classes[aURL].createInstance(ENIG_C.interfaces[aInterface]);
+}
+
+function enigGetInterface (aInterface) {
+  return rv = ENIG_C.interfaces[aInterface];
+}
+
+function enigGetService (aURL, aInterface) 
+{
+  // determine how 'aInterface' is passed and handle accordingly
+  switch (typeof(aInterface))
+  {
+    case "object":
+      return ENIG_C.classes[aURL].getService(aInterface);
+      break;
+
+    case "string":
+      return ENIG_C.classes[aURL].getService(ENIG_C.interfaces[aInterface]);
+      break;
+ 
+    default:
+      return ENIG_C.classes[aURL].getService();
+  }
+  
+  return null;
+}
