@@ -34,6 +34,7 @@ GPL.
 // Uses: chrome://enigmail/content/enigmailCommon.js
 
 // Initialize enigmailCommon
+
 EnigInitCommon("enigmailMessengerOverlay");
 
 var gEnigCreatedURIs = [];
@@ -167,7 +168,7 @@ function enigViewSecurityInfo(event, displaySmimeMsg) {
       }
 
     } else {
-      EnigAlert(EnigGetString("securityInfo")+gEnigSecurityInfo.statusInfo);
+      EnigLongAlert(EnigGetString("securityInfo")+gEnigSecurityInfo.statusInfo);
     }
 
   } else {
@@ -242,7 +243,7 @@ function enigMessageReload(noShowReload) {
 function enigMessageCleanup() {
   DEBUG_LOG("enigmailMessengerOverlay.js: MessageCleanup\n");
 
-  var enigmailBox = document.getElementById("expandedEnigmailBox");
+  var enigmailBox = document.getElementById("enigmailBox");
 
   if (enigmailBox && !enigmailBox.collapsed) {
     enigmailBox.setAttribute("collapsed", "true");
@@ -250,7 +251,7 @@ function enigMessageCleanup() {
     var statusText = document.getElementById("expandedEnigmailStatusText");
 
     if (statusText)
-      statusText.firstChild.data="";
+      statusText.value="";
   }
 
   if (gEnigCreatedURIs.length) {
@@ -766,7 +767,7 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
 
   if (importOnly) {
      if (interactive && errorMsg)
-       EnigAlert(errorMsg);
+       EnigLongAlert(errorMsg);
      return;
   }
 
@@ -784,7 +785,7 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
 
   if (!plainText) {
      if (interactive && gEnigSecurityInfo && gEnigSecurityInfo.statusInfo)
-       EnigAlert(gEnigSecurityInfo.statusInfo);
+       EnigLongAlert(gEnigSecurityInfo.statusInfo);
      return;
   }
 
@@ -1151,7 +1152,7 @@ function enigGetDecryptedMessage(contentType, includeHeaders) {
       contentData += "\r\n"+gEnigDecryptedMessage.plainText;
     }
 
-    if (!(enigmailSvc.isWin32)) {
+    if (!(enigmailSvc.isDosLike)) {
       contentData = contentData.replace(/\r\n/g, "\n");
     }
   }
@@ -1609,7 +1610,7 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
   }
   if (exitStatus) {
     if (statusFlagsObj.value & nsIEnigmail.IMPORTED_KEY) {
-      EnigAlert(EnigGetString("successKeyImport")+"\n\n"+errorMsgObj.value);
+      EnigLongAlert(EnigGetString("successKeyImport")+"\n\n"+errorMsgObj.value);
     }
     else if (statusFlagsObj.value & nsIEnigmail.DISPLAY_MESSAGE) {
       EnigLoadURLInNavigatorWindow(callbackArg.attachment.url, true)
@@ -1761,15 +1762,18 @@ function enigReceiveKeyTerminate (terminateArg, ipcRequest) {
   }
 
   var keyRetrProcess = gEnigIpcRequest.pipeTransport;
+  var enigmailSvc = GetEnigmailSvc();
   var exitCode;
 
   if (keyRetrProcess && !keyRetrProcess.isAttached()) {
     keyRetrProcess.terminate();
     exitCode = keyRetrProcess.exitCode();
     DEBUG_LOG("enigmailMessengerOverlay.js: enigReceiveKeyTerminate: exitCode = "+exitCode+"\n");
+    if (enigmailSvc) {
+      exitCode = enigmailSvc.fixExitCode(exitCode, 0);
+    }
   }
 
-  var enigmailSvc = GetEnigmailSvc();
   if (exitCode==0) {
     enigMessageReload(false);
     if (enigmailSvc) {
