@@ -135,9 +135,14 @@ function getRecipientsKeys(emailAddrs, forceSelection, matchedKeysObj, flagsObj)
           inputObj.command = "add";
           window.openDialog("chrome://enigmail/content/enigmailSingleRcptSettings.xul","", "dialog,modal,centerscreen,resizable", inputObj, resultObj);
           if (resultObj.cancelled==true) return false;
-          sign   =getFlagVal(sign,    resultObj.sign);
-          encrypt=getFlagVal(encrypt, resultObj.encrypt);
-          pgpMime=getFlagVal(pgpMime, resultObj.pgpMime);
+          
+          // create a getAttribute() function for getFlagVal to work normally
+          resultObj.getAttribute = function(attrName) {
+            return this[attrName]; 
+          }
+          sign   =getFlagVal(sign,    resultObj, "sign",    conflicts);
+          encrypt=getFlagVal(encrypt, resultObj, "encrypt", conflicts);
+          pgpMime=getFlagVal(pgpMime, resultObj, "pgpMime", conflicts);
           if (resultObj.keyId.length>0) {
             keyList.push(resultObj.keyId);
             var replaceAddr=new RegExp("{"+addrList[i]+"}", "g");
@@ -163,8 +168,10 @@ function getRecipientsKeys(emailAddrs, forceSelection, matchedKeysObj, flagsObj)
   flagsObj.value = 1;
 
   if ((!EnigGetPref("confirmBeforeSend")) && (conflicts.encrypt ||conflicts.sign)) {
-    var msg = "\n"+"- " + EnigGetString(sign ? "signYes" : "signNo");
-    msg += "\n"+"- " + EnigGetString(encrypt ? "encryptYes" : "encryptNo");
+    if (sign<2) sign = (sign & (gEnigSendMode & ENIG_SIGN));
+    if (encrypt<2) encrypt = (encrypt & (gEnigSendMode & ENIG_ENCRYPT ? 1 : 0));
+    var msg = "\n"+"- " + EnigGetString(sign>0 ? "signYes" : "signNo");
+    msg += "\n"+"- " + EnigGetString(encrypt>0 ? "encryptYes" : "encryptNo");
     if (EnigGetPref("warnOnRulesConflict")==2) {
       EnigSetPref("warnOnRulesConflict", 0);
     }
