@@ -20,10 +20,11 @@ var gMimeHashAlgorithms = ["md5", "sha1", "ripemd160"];
 
 var gEnigEditor;
 var gEnigDirty, gEnigProcessed, gEnigTimeoutID;
-var gEnigSendPGPMime, gEnigModifiedAttach, gEnigSendMode;
+var gEnigSendPGPMime, gEnigMeodifiedAttach, gEnigSendMode;
 var gEnigSendModeDirty = 0;
 var gEnigNextCommand;
 var gEnigIdentity = null;
+var gEnigEnableRules = null;
 
 if (typeof(GenericSendMessage)=="function") {
   // replace GenericSendMessage with our own version
@@ -77,6 +78,7 @@ function enigMsgComposeStartup() {
 
 
 function enigHandleClick(event, modifyType) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigHandleClick\n");
   switch (event.button) {
   case 2:
     // do not process the event any futher
@@ -92,23 +94,30 @@ function enigHandleClick(event, modifyType) {
 
 
 function enigSetIdentityCallback(elementId) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigSetIdentityCallback: elementId="+elementId+"\n");
   enigSetIdentityDefaults();
 }
 
 function enigGetAccDefault(value) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigGetAccDefault: identity="+gEnigIdentity.key+" value="+value+"\n");
 
   var enabled = gEnigIdentity.getBoolAttribute("enablePgp");
   if (value == "enabled")
     return enabled;
   if (enabled) {
+    var r=null;
     switch (value) {
     case 'encrypt':
-      return gEnigIdentity.getIntAttribute("defaultEncryptionPolicy");
+      r=gEnigIdentity.getIntAttribute("defaultEncryptionPolicy");
+      break;
     case 'signPlain':
-      return gEnigIdentity.getBoolAttribute("pgpSignPlain");
+      r=gEnigIdentity.getBoolAttribute("pgpSignPlain");
+      break;
     case 'signEnc':
-      return gEnigIdentity.getBoolAttribute("pgpSignEncrypted");
+      r=gEnigIdentity.getBoolAttribute("pgpSignEncrypted");
     }
+    DEBUG_LOG("  "+value+"="+r+"\n");
+    return r;
   }
   else {
     switch (value) {
@@ -123,8 +132,8 @@ function enigGetAccDefault(value) {
 }
 
 function enigSetIdentityDefaults() {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigSetIdentityDefaults\n");
   gEnigIdentity = getCurrentIdentity();
-  gEnigIdentity.getBoolAttribute("enablePgp");
   if (enigGetAccDefault("enabled")) {
     EnigGetSignMsg(gEnigIdentity);
   }
@@ -139,6 +148,7 @@ function enigSetIdentityDefaults() {
 // set the current default for sending a message
 // depending on the identity
 function enigSetSendDefaultOptions() {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigSetSendDefaultOptions\n");
   gEnigSendMode = 0;
   if (! enigGetAccDefault("enabled")) {
     return;
@@ -154,15 +164,23 @@ function enigSetSendDefaultOptions() {
 
 
 function enigComposeOpen() {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigComposeOpen\n");
   if (EnigGetPref("keepSettingsForReply") && (!(gEnigSendMode & ENIG_ENCRYPT))) {
     var enigMimeService = Components.classes[ENIG_ENIGMIMESERVICE_CONTRACTID].getService(Components.interfaces.nsIEnigMimeService);
     if (enigMimeService)
     {
-      if (enigMimeService.isEncrypted(gMsgCompose.originalMsgURI)) {
-        enigSetSendMode('encrypt');
+      if (typeof(gMsgCompose.originalMsgURI)=="string") {
+        if (gMsgCompose.originalMsgURI.length>0 && enigMimeService.isEncrypted(gMsgCompose.originalMsgURI)) {
+          DEBUG_LOG("enigmailMsgComposeOverlay.js: enigComposeOpen: has encrypted originalMsgUri\n");
+          DEBUG_LOG("originalMsgURI="+gMsgCompose.originalMsgURI+"\n");
+          enigSetSendMode('encrypt');
+        }
       }
-      else if (typeof(gMsgCompose.compFields.draftId)=="string") {
-        if (enigMimeService.isEncrypted(gMsgCompose.compFields.draftId.replace(/\?.*$/, ""))) {
+      if (typeof(gMsgCompose.compFields.draftId)=="string") {
+        if (gMsgCompose.compFields.draftId.length>0 && enigMimeService.isEncrypted(gMsgCompose.compFields.draftId.replace(/\?.*$/, ""))) {
+          DEBUG_LOG("enigmailMsgComposeOverlay.js: enigComposeOpen: has encrypted draftId=");
+          DEBUG_LOG(gMsgCompose.compFields.draftId);
+          DEBUG_LOG(" encrypted="+enigMimeService.isEncrypted(gMsgCompose.compFields.draftId)+"\n");
           enigSetSendMode('encrypt');
         }
       }
@@ -196,6 +214,7 @@ function enigMsgComposeReset() {
   gEnigModifiedAttach=null;
   gEnigSendModeDirty = 0;
   gEnigSendMode = 0;
+  gEnigEnableRules = true;
   gEnigIdentity = null;
 
   EnigShowHeadersAll(true);
@@ -279,8 +298,7 @@ function enigInsertKey() {
   var exitCodeObj = new Object();
   var errorMsgObj = new Object();
 
-  var uiFlags = nsIEnigmail.UI_INTERACTIVE;
-  var keyBlock = enigmailSvc.extractKey(window, uiFlags, userIdValue,
+  var keyBlock = enigmailSvc.extractKey(window, 0, userIdValue, null,
                                         exitCodeObj, errorMsgObj);
   var exitCode = exitCodeObj.value;
 
@@ -331,6 +349,7 @@ function enigUndoEncryption() {
 }
 
 function enigReplaceEditorText(text) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigReplaceEditorText:\n");
   EnigEditorSelectAll();
 
   // Overwrite text in clipboard for security
@@ -343,6 +362,7 @@ function enigReplaceEditorText(text) {
 
 function enigGoAccountManager()
 {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigGoAccountManager:\n");
   var server=null;
   try {
       var currentId=getCurrentIdentity();
@@ -355,6 +375,7 @@ function enigGoAccountManager()
 }
 
 function enigDoPgpButton(what) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigDoPgpButton: what="+what+"\n");
   if (! what)
     what = gEnigNextCommand;
   gEnigNextCommand = "";
@@ -386,6 +407,10 @@ function enigDoPgpButton(what) {
       enigTogglePGPMime();
       break;
 
+    case 'toggleRules':
+      enigToggleRules();
+      break;
+
     default:
       enigDisplaySecuritySettings();
   }
@@ -393,11 +418,12 @@ function enigDoPgpButton(what) {
 }
 
 function enigNextCommand(what) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigNextCommand: what="+what+"\n");
   gEnigNextCommand=what;
 }
 
 function enigSetSendMode(sendMode) {
-  DEBUG_LOG("enigmailMessengerOverlay.js: enigSetSendMode\n");
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigSetSendMode: sendMode="+sendMode+"\n");
   var origSendMode=gEnigSendMode;
   switch (sendMode) {
     case 'toggle-sign':
@@ -450,7 +476,7 @@ function enigSetSendMode(sendMode) {
 }
 
 function enigDisplayUi() {
-
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigDisplayUi:\n");
   var statusBar = document.getElementById("enigmail-status-bar");
 
   if (!enigGetAccDefault("enabled")) {
@@ -483,6 +509,7 @@ function enigDisplayUi() {
 }
 
 function enigSetMenuSettings(postfix) {
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigSetMenuSettings: postfix="+postfix+"\n");
   document.getElementById("enigmail_encrypted_send"+postfix).setAttribute("checked",(gEnigSendMode & ENIG_ENCRYPT) ? true : false);
   document.getElementById("enigmail_signed_send"+postfix).setAttribute("checked",(gEnigSendMode & ENIG_SIGN) ? true : false);
 
@@ -490,12 +517,17 @@ function enigSetMenuSettings(postfix) {
   if (menuElement)
     menuElement.setAttribute("checked", gEnigSendPGPMime ? "true" : "false");
 
+  menuElement = document.getElementById("enigmail_disable_rules"+postfix);
+  if (menuElement)
+    menuElement.setAttribute("checked", gEnigEnableRules ? "false" : "true");
+
 }
 
 function enigDisplaySecuritySettings() {
-
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigDisplaySecuritySettings\n");
   var inputObj = { sendFlags: gEnigSendMode,
-                   usePgpMime: gEnigSendPGPMime};
+                   usePgpMime: gEnigSendPGPMime,
+                   disableRules: gEnigEnableRules};
   window.openDialog("chrome://enigmail/content/enigmailEncryptionDlg.xul","", "dialog,modal,centerscreen", inputObj);
   if (gEnigSendMode != inputObj.sendFlags) {
     gEnigDirty = 2;
@@ -506,6 +538,7 @@ function enigDisplaySecuritySettings() {
 }
 
 function enigDisplaySignClickWarn() {
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigDisplaySignClickWarn\n");
   if ((gEnigSendModeDirty<2) &&
       (enigGetAccDefault("signPlain") ||
        enigGetAccDefault("signEnc"))) {
@@ -514,6 +547,7 @@ function enigDisplaySignClickWarn() {
 }
 
 function enigConfirmBeforeSend(toAddr, gpgKeys, sendFlags, isOffline, msgSendType) {
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigConfirmBeforeSend: sendFlags="+sendFlags+"\n");
   // get confirmation before sending message
   var msgStatus = "";
 
@@ -763,7 +797,7 @@ function enigEncryptMsg(msgSendType) {
         var perRecipientRules=EnigGetPref("perRecipientRules");
         var repeatSelection=0;
         while (repeatSelection<2) {
-          if (perRecipientRules>0) {
+          if (perRecipientRules>0 && gEnigEnableRules) {
             var matchedKeysObj = new Object;
             var flagsObj=new Object;
             if (!getRecipientsKeys(toAddr, 
@@ -850,7 +884,7 @@ function enigEncryptMsg(msgSendType) {
                     window.cancelSendMessage=true;
                     return;
                   }
-                  if (resultObj.perRecipientRules) {
+                  if (resultObj.perRecipientRules && gEnigEnableRules) {
                     // do an extra round because the user want to set a PGP rule
                     continue;
                   }
@@ -865,7 +899,6 @@ function enigEncryptMsg(msgSendType) {
                   testExitCodeObj.value = 0;
                 } catch (ex) {
                   // cancel pressed -> don't send mail
-                  EnigAlert("Something went wrong 1"); // REMOVE
                   window.cancelSendMessage=true;
                   return;
                 }
@@ -1263,9 +1296,8 @@ function enigModifyCompFields(msgCompFields) {
 // Modified version of GenericSendMessage from the file MsgComposeCommands.js
 function enigGenericSendMessage( msgType )
 {
-  dump("enigGenericSendMessage from XUL\n");
-
-  dump("Identity = " + gEnigIdentity + "\n");
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigGenericSendMessage: msgType="+msgType+"\n");
+  DEBUG_LOG("  Identity = " + gEnigIdentity + "\n");
 
   if (gMsgCompose != null)
   {
@@ -1308,7 +1340,8 @@ function enigGenericSendMessage( msgType )
         }            
 
         //Check if we have a subject, else ask user for confirmation
-        if (subject == "")
+        
+        if (subject == "" && (! EnigGetPref("allowEmptySubject")))
         {
           if (gEnigPromptSvc)
           {
@@ -1351,19 +1384,21 @@ function enigGenericSendMessage( msgType )
         }
         switch (action)
         {
-          case nsIMsgCompSendFormat.PlainText:
-            msgCompFields.forcePlainText = true;
-            msgCompFields.useMultipartAlternative = false;
-            break;
-          case nsIMsgCompSendFormat.HTML:
-            msgCompFields.forcePlainText = false;
-            msgCompFields.useMultipartAlternative = false;
-            break;
-          case nsIMsgCompSendFormat.Both:
-            msgCompFields.forcePlainText = false;
-            msgCompFields.useMultipartAlternative = true;
-            break;
-           default: dump("\###SendMessage Error: invalid action value\n"); return;
+        case nsIMsgCompSendFormat.PlainText:
+          msgCompFields.forcePlainText = true;
+          msgCompFields.useMultipartAlternative = false;
+          break;
+        case nsIMsgCompSendFormat.HTML:
+          msgCompFields.forcePlainText = false;
+          msgCompFields.useMultipartAlternative = false;
+          break;
+        case nsIMsgCompSendFormat.Both:
+          msgCompFields.forcePlainText = false;
+          msgCompFields.useMultipartAlternative = true;
+          break;
+        default: 
+          ERROR_LOG("\###SendMessage Error: invalid action value\n");
+          return;
         }
       }
 
@@ -1458,7 +1493,7 @@ function enigGenericSendMessage( msgType )
         }
       }
       catch (ex) {
-        dump("failed to SendMsg: " + ex + "\n");
+        ERROR_LOG("failed to SendMsg: " + ex + "\n");
         gWindowLocked = false;
         enableEditableFields();
         CommandUpdate_MsgCompose();
@@ -1466,7 +1501,7 @@ function enigGenericSendMessage( msgType )
     }
   }
   else
-    dump("###SendMessage Error: composeAppCore is null!\n");
+    ERROR_LOG("###SendMessage Error: composeAppCore is null!\n");
 }
 
 
@@ -1602,6 +1637,11 @@ function enigToggleAccountAttr(attrName)
 
 }
 
+function enigToggleRules() {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigToggleRules: gEnigEnableRules="+gEnigEnableRules+"\n");
+  gEnigEnableRules = !gEnigEnableRules;
+}
+
 function enigDecryptQuote(interactive) {
   DEBUG_LOG("enigmailMsgComposeOverlay.js: enigDecryptQuote: "+interactive+"\n");
 
@@ -1944,8 +1984,7 @@ function EnigEditorGetContentsAs(mimeType, flags) {
   }
 }
 
-function EnigComposeStateListener() {
-}
+function EnigComposeStateListener() {}
 
 EnigComposeStateListener.prototype = {
   NotifyComposeFieldsReady: function() {
@@ -1976,9 +2015,7 @@ EnigComposeStateListener.prototype = {
   }
 };
 
-function EnigDocStateListener()
-{
-}
+function EnigDocStateListener() {}
 
 EnigDocStateListener.prototype = {
 
@@ -2043,4 +2080,4 @@ EnigDocStateListener.prototype = {
       gEnigTimeoutID = window.setTimeout(enigDecryptQuote, 10, false);
   }
 }
-  
+
