@@ -66,7 +66,7 @@ function enigStartHeaders()
   gEnigStatusBar.removeAttribute("signed");
   gEnigStatusBar.removeAttribute("encrypted");
 
-  var enigmailBox = document.getElementById("expandedEnigmailBox");
+  var enigmailBox = document.getElementById("enigmailBox");
   var statusText = document.getElementById("enigmailStatusText");
 
   if (enigmailBox && !enigmailBox.collapsed) {
@@ -76,7 +76,7 @@ function enigStartHeaders()
   }
   
   if (statusText)
-    statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureOk");
+    statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
 
   statusText = document.getElementById("collapsedEnigmailStatusText");
 
@@ -85,7 +85,7 @@ function enigStartHeaders()
   }
   
   if (statusText)
-    statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureOk");
+    statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
 
   var msgFrame = EnigGetFrame(window, "messagepane");
 
@@ -113,12 +113,12 @@ function enigEndHeaders()
   gEnigStatusBar.removeAttribute("encrypted");
   var statusText = document.getElementById("enigmailStatusText");
   if (statusText) {
-    statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureOk");
+    statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
   }
   
   statusText = document.getElementById("collapsedEnigmailStatusText");
   if (statusText) {
-    statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureOk");
+    statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
   }
 }
 
@@ -161,17 +161,20 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     userId=EnigConvertGpgToUnicode(replaceUid);
   }
 
+  var errorLines="";
+  var fullStatusInfo="";
+
   if (exitCode == ENIG_POSSIBLE_PGPMIME) {
     exitCode = 0;
   }
   else {
-    errorMsg=EnigConvertGpgToUnicode(errorMsg);
+    if (errorMsg) {
+      errorMsg=EnigConvertGpgToUnicode(errorMsg);
+      errorLines = errorMsg.split(/\r?\n/);
+      fullStatusInfo=errorMsg;
+    }
   }
   
-  var errorLines="";
-  var fullStatusInfo=errorMsg;
-  if (errorMsg)
-     errorLines = errorMsg.split(/\r?\n/);
 
   if (errorLines && (errorLines.length > 22) ) {
     // Retain only first twenty lines and last two lines of error message
@@ -208,7 +211,10 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
             nsIEnigmail.DECRYPTION_INCOMPLETE |
             nsIEnigmail.DECRYPTION_FAILED));
 
-  if ((exitCode == 0 ||
+  if (((!(statusFlags & (nsIEnigmail.DECRYPTION_INCOMPLETE |
+            nsIEnigmail.DECRYPTION_FAILED |
+            nsIEnigmail.UNVERIFIED_SIGNATURE |
+            nsIEnigmail.BAD_SIGNATURE))) ||
        (statusFlags & nsIEnigmail.DISPLAY_MESSAGE)) &&
         !(statusFlags & (nsIEnigmail.UNVERIFIED_SIGNATURE |
           nsIEnigmail.IMPORTED_KEY))) {
@@ -218,6 +224,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     
     if (sigDetails) {
       var detailArr=sigDetails.split(/ /);
+
       var dat=new Date(detailArr[2]*1000);
       var appLocale = Components.classes[ENIG_LOCALE_SVC_CONTRACTID].getService(Components.interfaces.nsILocaleService).getApplicationLocale();
       var dateFormat = Components.classes[ENIG_DATE_FORMAT_CONTRACTID].getService(Components.interfaces.nsIScriptableDateFormat);
@@ -226,22 +233,19 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                           dateFormat.timeFormatNoSeconds,
                           dat.getFullYear(), dat.getMonth()+1, dat.getDate(),
                           dat.getHours(), dat.getMinutes(), 0);
-      var txt = EnigGetString("keyAndSigDate", detailArr[0].substr(-8, 8), dateTime);
+      var txt = EnigGetString("keyAndSigDate", keyId.substr(-8, 8), dateTime);
       statusArr.push(txt);
       statusInfo += "\n" + txt;
-      // 933D 9948 DC0F A861 471B 10A9 D8A8 07C7 CCEC 227B
-      // 4628 4358 0136 4A06 B9EA FE9D 3C5D F224
-      var fpr = detailArr[0].match(/^(....)(....)(....)(....)(....)(....)(....)(....)(....)?(....)?$/);
-      if (fpr && fpr.length > 2) {
-        fpr.shift()
-        statusInfo += "\n"+EnigGetString("keyFpr",fpr.join(" "));
+      var fpr = EnigFormatFpr(detailArr[0]);
+      if (fpr) {
+        statusInfo += "\n"+EnigGetString("keyFpr", fpr);
       }
     }
     fullStatusInfo = statusInfo;
 
   } else {
-    if (keyId) {
-      statusInfo = EnigGetString("keyNeeded",keyId);
+      if (keyId) {
+        statusInfo = EnigGetString("keyNeeded",keyId);
   
       if (statusFlags & nsIEnigmail.INLINE_KEY) {
         statusLine = statusInfo + EnigGetString("clickDecrypt");
@@ -333,23 +337,24 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                         keyId: keyId,
                         userId: userId,
                         statusLine: statusLine,
+                        msgSigned: msgSigned,
                         statusArr: statusArr,
                         statusInfo: statusInfo,
                         fullStatusInfo: fullStatusInfo };
 
-  var enigmailBox = document.getElementById("expandedEnigmailBox");
+  var enigmailBox = document.getElementById("enigmailBox");
   var statusText  = document.getElementById("enigmailStatusText");
   var expStatusText  = document.getElementById("expandedEnigmailStatusText");
 
   if (statusArr.length>0) {
-    expStatusText.firstChild.data = statusArr[0];
+    expStatusText.value = statusArr[0];
     expStatusText.setAttribute("state", "true");
   }
   else {
-    expStatusText.firstChild.data = "*";
+    expStatusText.value = "";
     expStatusText.setAttribute("state", "false");
   }
-  
+
   if (statusLine) {
     statusText.value = statusLine +" ";
     enigmailBox.removeAttribute("collapsed");
@@ -372,8 +377,8 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     if (statusFlags & nsIEnigmail.BAD_SIGNATURE) {
       // Display untrusted/bad signature icon
       gSignedUINode.setAttribute("signed", "notok");
-      statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureNotOk");
-      expStatusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureNotOk");
+      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureNotOk");
+      expStatusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureNotOk");
       gEnigStatusBar.setAttribute("signed", "notok");
     }
     else if ((statusFlags & nsIEnigmail.GOOD_SIGNATURE) &&
@@ -383,8 +388,8 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                        nsIEnigmail.EXPIRED_SIGNATURE))) {
       // Display trusted good signature icon
       gSignedUINode.setAttribute("signed", "ok");
-      statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureOk");
-      expStatusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureOk");
+      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
+      expStatusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
       gEnigStatusBar.setAttribute("signed", "ok");
     }
     else if (statusFlags & (nsIEnigmail.UNVERIFIED_SIGNATURE |
@@ -394,8 +399,8 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
                        nsIEnigmail.GOOD_SIGNATURE)) {
       // Display unverified signature icon
       gSignedUINode.setAttribute("signed", "unknown");
-      statusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureUnknown");
-      expStatusText.setAttribute("class", "enigmailHeaderBoxLabelSignatureUnknown");
+      statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureUnknown");
+      expStatusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureUnknown");
       gEnigStatusBar.setAttribute("signed", "unknown");
     }
 
@@ -421,7 +426,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
 }
 
 function enigDispSecurityContext() {
-  var optList = ["pgpSecurityInfo", "copySecurityInfo", "showPhoto"];
+  var optList = ["pgpSecurityInfo", "copySecurityInfo"];
   for (var j=0; j<optList.length; j++) {
     var menuElement = document.getElementById("enigmail_"+optList[j]);
     if (gEnigSecurityInfo) {
@@ -431,14 +436,55 @@ function enigDispSecurityContext() {
       menuElement.setAttribute("disabled", "true");
     }
   }
+  
+  enigSetSenderStatus("signSenderKey", "editSenderKeyTrust" , "showPhoto");
+}
 
+
+function enigUpdateSendersKeyMenu() {
+  enigSetSenderStatus("keyMgmtSignKey", "keyMgmtKeyTrust", "keyMgmtShowPhoto")
+}
+
+
+function enigSetSenderStatus(elemSign, elemTrust, elemPhoto) {
+  var photo=false;
+  var sign=false;
+  var trust=false;
   if (gEnigSecurityInfo) {
-    if (! (gEnigSecurityInfo.statusFlags & nsIEnigmail.PHOTO_AVAILABLE)) {
-      document.getElementById("enigmail_showPhoto").setAttribute("disabled", "true");
+    if (gEnigSecurityInfo.statusFlags & nsIEnigmail.PHOTO_AVAILABLE) {
+      photo=true;
+    }
+    if (gEnigSecurityInfo.msgSigned ) {
+      if (!(gEnigSecurityInfo.statusFlags & 
+           (nsIEnigmail.REVOKED_KEY | nsIEnigmail.EXPIRED_KEY_SIGNATURE | nsIEnigmail.UNVERIFIED_SIGNATURE))) {
+        sign=true;
+      }
+      if (!(gEnigSecurityInfo.statusFlags & nsIEnigmail.UNVERIFIED_SIGNATURE)) {
+        trust=true;
+      }
     }
   }
+
+  if (elemTrust)
+    document.getElementById("enigmail_"+elemTrust).setAttribute("disabled", !trust);
+  if (elemSign)
+    document.getElementById("enigmail_"+elemSign).setAttribute("disabled", !sign);
+  if (elemPhoto)
+    document.getElementById("enigmail_"+elemPhoto).setAttribute("disabled", !photo);
+  
 }
 
+function enigEditKeyTrust() {
+  EnigEditKeyTrust([gEnigSecurityInfo.userId], [gEnigSecurityInfo.keyId]);
+  ReloadWithAllParts();
+}
+
+function enigSignKey() {
+  EnigSignKey(gEnigSecurityInfo.userId, gEnigSecurityInfo.keyId, null)
+  ReloadWithAllParts();
+}
+
+
 function enigMsgHdrViewLoad(event)
 {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigMsgHdrViewLoad\n");
@@ -469,41 +515,10 @@ function enigCopyStatusInfo() {
 }
 
 function enigShowPhoto() {
-
   if (! gEnigSecurityInfo)
     return
 
-  var enigmailSvc = GetEnigmailSvc();
-  if (enigmailSvc) {
-    var exitCodeObj = new Object();
-    var errorMsgObj = new Object();
-    var photoPath = enigmailSvc.showKeyPhoto("0x"+gEnigSecurityInfo.keyId, exitCodeObj, errorMsgObj);
-    if (photoPath && exitCodeObj.value==0) {
-      var photoFile = Components.classes[ENIG_LOCAL_FILE_CONTRACTID].createInstance(Components.interfaces.nsILocalFile);
-      photoFile.initWithPath(photoPath);
-      if (! (photoFile.isFile() && photoFile.isReadable())) {
-        EnigAlert("Photo path '"+photoPath+"' is not readable");
-      }
-      else {
-        var ioServ = Components.classes[ENIG_IOSERVICE_CONTRACTID].getService(Components.interfaces.nsIIOService);
-        var photoUri = ioServ.newFileURI(photoFile).spec;
-        var argsObj = {
-          photoUri: photoUri,
-          userId: gEnigSecurityInfo.userId,
-          keyId: gEnigSecurityInfo.keyId
-        };
-        window.openDialog("chrome://enigmail/content/enigmailDispPhoto.xul",photoUri, "chrome,modal=1,resizable=1,dialog=1,centerscreen", argsObj);
-        try {
-          // delete the photo file
-          photoFile.remove(false);
-        }
-        catch (ex) {}
-     }
-    }
-    else {
-      EnigAlert("No Photo available");
-    }
-  }
+  EnigShowPhoto(gEnigSecurityInfo.keyId, gEnigSecurityInfo.userId);
 }
 
 function enigCreateRuleFromAddress(emailAddressNode) {
@@ -527,8 +542,8 @@ function enigForgetEncryptedURI()
 
 function enigMsgHdrViewHide() {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigMsgHdrViewHide\n");
-  var enigmailBox = document.getElementById("expandedEnigmailBox");
-  enigmailBox.collapsed=true;
+  var enigmailBox = document.getElementById("enigmailBox");
+  enigmailBox.setAttribute("collapsed", true);
 
   gEnigSecurityInfo = { statusFlags: 0,
                       keyId: "",
@@ -537,14 +552,13 @@ function enigMsgHdrViewHide() {
                       statusInfo: "",
                       fullStatusInfo: "" };
 
-
 }
 
 function enigMsgHdrViewUnhide() {
   DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigMsgHdrViewUnhide\n");
   if (gEnigSecurityInfo.statusFlags != 0) {
-    var enigmailBox = document.getElementById("expandedEnigmailBox");
-    enigmailBox.collapsed=false;
+    var enigmailBox = document.getElementById("enigmailBox");
+    enigmailBox.removeAttribute("collapsed");
   }
 }
 
@@ -628,8 +642,6 @@ if (messageHeaderSink) {
   // Use the pref "extensions.enigmail.show_headers"
   // instead of "mail.show_headers"
 
-  //dump("messageHeaderSink="+messageHeaderSink+"\n");
-
   messageHeaderSink.onStartHeaders = function()
   {
     DEBUG_LOG("enigmailMsgHdrViewOverlay.js: messageHeaderSink.onStartHeaders: START\n");
@@ -665,7 +677,11 @@ if (messageHeaderSink) {
     gBuildAttachmentPopupForCurrentMsg = true;
     ClearAttachmentList();
     ClearEditMessageButton();
-
+    
+    // TB 0.8 and newer
+    if (typeof(SetUpRemoteContentBar) == "function")
+      SetUpRemoteContentBar(null);
+      
     for (index in gMessageListeners)
       gMessageListeners[index].onStartHeaders();
 
